# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.notification_request import NotificationRequest

class TestNotificationRequest(unittest.TestCase):
    """NotificationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NotificationRequest:
        """Test NotificationRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotificationRequest`
        """
        model = NotificationRequest()
        if include_optional:
            return NotificationRequest(
                event = authentik_client.models.event_request.EventRequest(
                    user = null, 
                    action = 'login', 
                    app = '0', 
                    context = null, 
                    client_ip = '0', 
                    expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    brand = null, ),
                seen = True
            )
        else:
            return NotificationRequest(
        )
        """

    def testNotificationRequest(self):
        """Test NotificationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
