# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.microsoft_entra_provider_request import MicrosoftEntraProviderRequest

class TestMicrosoftEntraProviderRequest(unittest.TestCase):
    """MicrosoftEntraProviderRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MicrosoftEntraProviderRequest:
        """Test MicrosoftEntraProviderRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MicrosoftEntraProviderRequest`
        """
        model = MicrosoftEntraProviderRequest()
        if include_optional:
            return MicrosoftEntraProviderRequest(
                name = '0',
                property_mappings = [
                    ''
                    ],
                property_mappings_group = [
                    ''
                    ],
                client_id = '0',
                client_secret = '0',
                tenant_id = '0',
                exclude_users_service_account = True,
                filter_group = '',
                user_delete_action = 'do_nothing',
                group_delete_action = 'do_nothing'
            )
        else:
            return MicrosoftEntraProviderRequest(
                name = '0',
                client_id = '0',
                client_secret = '0',
                tenant_id = '0',
        )
        """

    def testMicrosoftEntraProviderRequest(self):
        """Test MicrosoftEntraProviderRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
