# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2024.12.3
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.extra_user_object_permission import ExtraUserObjectPermission

class TestExtraUserObjectPermission(unittest.TestCase):
    """ExtraUserObjectPermission unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExtraUserObjectPermission:
        """Test ExtraUserObjectPermission
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExtraUserObjectPermission`
        """
        model = ExtraUserObjectPermission()
        if include_optional:
            return ExtraUserObjectPermission(
                id = 56,
                codename = '',
                model = '',
                app_label = '',
                object_pk = '',
                name = '',
                app_label_verbose = '',
                model_verbose = '',
                object_description = ''
            )
        else:
            return ExtraUserObjectPermission(
                id = 56,
                codename = '',
                model = '',
                app_label = '',
                object_pk = '',
                name = '',
                app_label_verbose = '',
                model_verbose = '',
                object_description = '',
        )
        """

    def testExtraUserObjectPermission(self):
        """Test ExtraUserObjectPermission"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
